@@ -156,6 +156,9 @@ class ZoteroImporter(Importer):
             cached_data["Zotero"] = {}
         cached_data["Zotero"].update(tokens)
 
+        if not cache_path.parent.exists():
+            cache_path.parent.mkdir(parents=True)
+
         with open(cache_path, "w", encoding="utf-8") as cache:
             json.dump(cached_data, cache)
 
@@ -245,7 +248,7 @@ class ZoteroImporter(Importer):
         if pre_hook_result is not None:
             protected_url, authentication = pre_hook_result
 
-        raw_result = requests.get(protected_url, headers=authentication)
+        raw_result = requests.get(protected_url, headers=authentication, timeout=30)
 
         bibtex_parser = BibtexParser()
 
