@@ -1,5 +1,5 @@
 """Tests for coBib's TUI."""
-# pylint: disable=no-self-use,unused-argument,too-many-public-methods
+# pylint: disable=unused-argument,too-many-public-methods
 
 import copy
 import tempfile
@@ -967,7 +967,7 @@ class TestTUI(CmdLineTest, TUITest):
             else:
                 assert screen.display[1][:2] == "kn"
 
-        self.run_tui([SIGWINCH] + list(keys), assertion, assertion_kwargs)  # type: ignore
+        self.run_tui([SIGWINCH] + list(keys), assertion, assertion_kwargs)
 
     @pytest.mark.parametrize(
         ["kwargs"],
