@@ -27,7 +27,7 @@ def setup_remove_content_length(monkeypatch: pytest.MonkeyPatch, enable: bool =
 
     def remove_content_length(*args, **kwargs):  # type: ignore
         """Mock function to remove `content-length` from response."""
-        response = requests.request("get", *args, **kwargs)
+        response = requests.request("get", *args, timeout=kwargs.pop("timeout", 30), **kwargs)
         response.headers.pop("content-length")
         return response
 
@@ -44,7 +44,7 @@ def test_downloader_singleton() -> None:
 def test_set_logger() -> None:
     """Test the FileDownloader.set_logger method."""
     f_d = FileDownloader()
-    logger = lambda text: f"test: {text}"
+    logger = lambda text: f"test: {text}"  # pylint: disable=unnecessary-lambda-assignment
     f_d.set_logger(logger)  # type: ignore
     # pylint: disable=protected-access
     assert FileDownloader._logger("") == "test: "  # type: ignore
